Author: brane
Date: Wed May  8 14:34:57 2013
New Revision: 1480294

URL: http://svn.apache.org/r1480294
Log:
Sync wc-collate-path branch with trunk up to r1480292.

Modified:
    subversion/branches/wc-collate-path/   (props changed)
    subversion/branches/wc-collate-path/build/ac-macros/compiler.m4
    subversion/branches/wc-collate-path/configure.ac
    
subversion/branches/wc-collate-path/subversion/bindings/swig/perl/libsvn_swig_perl/swigutil_pl.c
    subversion/branches/wc-collate-path/subversion/include/svn_error_codes.h
    subversion/branches/wc-collate-path/subversion/libsvn_client/add.c
    subversion/branches/wc-collate-path/subversion/libsvn_client/merge.c
    subversion/branches/wc-collate-path/subversion/libsvn_client/ra.c
    subversion/branches/wc-collate-path/subversion/libsvn_ra_serf/serf.c
    subversion/branches/wc-collate-path/subversion/libsvn_subr/cache-membuffer.c
    subversion/branches/wc-collate-path/subversion/libsvn_subr/sqlite3wrapper.c
    subversion/branches/wc-collate-path/subversion/po/sv.po
    subversion/branches/wc-collate-path/subversion/svnmucc/svnmucc.c
    
subversion/branches/wc-collate-path/subversion/tests/libsvn_wc/wc-queries-test.c
    subversion/branches/wc-collate-path/tools/dev/build-svn-deps-win.pl

Propchange: subversion/branches/wc-collate-path/
------------------------------------------------------------------------------
  Merged /subversion/trunk:r1479899-1480292

Modified: subversion/branches/wc-collate-path/build/ac-macros/compiler.m4
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/build/ac-macros/compiler.m4?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- subversion/branches/wc-collate-path/build/ac-macros/compiler.m4 (original)
+++ subversion/branches/wc-collate-path/build/ac-macros/compiler.m4 Wed May  8 
14:34:57 2013
@@ -66,6 +66,10 @@ AC_DEFUN([SVN_CC_MODE_SETUP],
     ])
   ])
 
+  dnl clang does not (always?) error out on unknown compiler
+  dnl options so silence the diagnostics emitted for warning options
+  SVN_CFLAGS_ADD_IFELSE([-Wno-unknown-warning-option])
+
   CMODEFLAGS="$CFLAGS"
   CFLAGS="$CFLAGS_KEEP"
   AC_SUBST(CMODEFLAGS)
@@ -82,6 +86,10 @@ AC_DEFUN([SVN_CXX_MODE_SETUP],
                 dnl g++ and clang++
   SVN_CXXFLAGS_ADD_IFELSE([-std=c++98])
 
+  dnl clang++ does not (always?) error out on unknown compiler
+  dnl options so silence the diagnostics emitted for warning options
+  SVN_CXXFLAGS_ADD_IFELSE([-Wno-unknown-warning-option])
+
   CXXMODEFLAGS="$CXXFLAGS"
   CXXFLAGS="$CXXFLAGS_KEEP"
   AC_SUBST(CXXMODEFLAGS)

Modified: subversion/branches/wc-collate-path/configure.ac
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/configure.ac?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- subversion/branches/wc-collate-path/configure.ac (original)
+++ subversion/branches/wc-collate-path/configure.ac Wed May  8 14:34:57 2013
@@ -1086,7 +1086,8 @@ if test "$enable_optimization" = "yes"; 
         SVN_CFLAGS_ADD_IFELSE([-O2],[],[
           SVN_CFLAGS_ADD_IFELSE([-O1],[],[
             SVN_CFLAGS_ADD_IFELSE([-O])])])])
-      SVN_CFLAGS_ADD_IFELSE([-flto -Wno-clobbered])
+      SVN_CFLAGS_ADD_IFELSE([-Wno-clobbered])
+      SVN_CFLAGS_ADD_IFELSE([-flto])
       SVN_CFLAGS_ADD_IFELSE([-fwhole-program])
     fi
   fi
@@ -1102,7 +1103,8 @@ if test "$enable_optimization" = "yes"; 
         SVN_CXXFLAGS_ADD_IFELSE([-O2],[],[
           SVN_CXXFLAGS_ADD_IFELSE([-O1],[],[
             SVN_CXXFLAGS_ADD_IFELSE([-O])])])])
-      SVN_CXXFLAGS_ADD_IFELSE([-flto -Wno-clobbered])
+      SVN_CXXFLAGS_ADD_IFELSE([-Wno-clobbered])
+      SVN_CXXFLAGS_ADD_IFELSE([-flto])
       SVN_CXXFLAGS_ADD_IFELSE([-fwhole-program])
     fi
   fi

Modified: 
subversion/branches/wc-collate-path/subversion/bindings/swig/perl/libsvn_swig_perl/swigutil_pl.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/subversion/bindings/swig/perl/libsvn_swig_perl/swigutil_pl.c?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- 
subversion/branches/wc-collate-path/subversion/bindings/swig/perl/libsvn_swig_perl/swigutil_pl.c
 (original)
+++ 
subversion/branches/wc-collate-path/subversion/bindings/swig/perl/libsvn_swig_perl/swigutil_pl.c
 Wed May  8 14:34:57 2013
@@ -303,6 +303,11 @@ const apr_array_header_t *svn_swig_pl_ar
     }
 
     croak("must pass a single revision range or a reference to an array of 
revision ranges");
+
+    /* This return is actually unreachable because of the croak above,
+     * however, Visual Studio's compiler doesn't like if all paths don't have
+     * a return and errors out otherwise. */ 
+    return NULL;
 }
 
 /* element convertors for c -> perl */

Modified: 
subversion/branches/wc-collate-path/subversion/include/svn_error_codes.h
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/subversion/include/svn_error_codes.h?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- subversion/branches/wc-collate-path/subversion/include/svn_error_codes.h 
(original)
+++ subversion/branches/wc-collate-path/subversion/include/svn_error_codes.h 
Wed May  8 14:34:57 2013
@@ -1275,7 +1275,7 @@ SVN_ERROR_START
   /** @since New in 1.6. */
   SVN_ERRDEF(SVN_ERR_NO_APR_MEMCACHE,
              SVN_ERR_MISC_CATEGORY_START + 28,
-             "apr memcache library not available")
+             "APR memcache library not available")
 
   /** @since New in 1.6. */
   SVN_ERRDEF(SVN_ERR_ATOMIC_INIT_FAILURE,

Modified: subversion/branches/wc-collate-path/subversion/libsvn_client/add.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/subversion/libsvn_client/add.c?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- subversion/branches/wc-collate-path/subversion/libsvn_client/add.c 
(original)
+++ subversion/branches/wc-collate-path/subversion/libsvn_client/add.c Wed May  
8 14:34:57 2013
@@ -1131,7 +1131,7 @@ mkdir_urls(const apr_array_header_t *url
 
       if (*bname == '\0')
         return svn_error_createf(SVN_ERR_ILLEGAL_TARGET, NULL,
-                                 _("There is no valid uri above '%s'"),
+                                 _("There is no valid URI above '%s'"),
                                  common);
     }
   else
@@ -1158,7 +1158,7 @@ mkdir_urls(const apr_array_header_t *url
 
           if (*bname == '\0')
              return svn_error_createf(SVN_ERR_ILLEGAL_TARGET, NULL,
-                                      _("There is no valid uri above '%s'"),
+                                      _("There is no valid URI above '%s'"),
                                       common);
 
           for (i = 0; i < targets->nelts; i++)

Modified: subversion/branches/wc-collate-path/subversion/libsvn_client/merge.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/subversion/libsvn_client/merge.c?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- subversion/branches/wc-collate-path/subversion/libsvn_client/merge.c 
(original)
+++ subversion/branches/wc-collate-path/subversion/libsvn_client/merge.c Wed 
May  8 14:34:57 2013
@@ -436,7 +436,7 @@ check_repos_match(const merge_target_t *
   if (!svn_uri__is_ancestor(target->loc.repos_root_url, url))
     return svn_error_createf(
         SVN_ERR_UNSUPPORTED_FEATURE, NULL,
-         _("Url '%s' of '%s' is not in repository '%s'"),
+         _("URL '%s' of '%s' is not in repository '%s'"),
          url, svn_dirent_local_style(local_abspath, scratch_pool),
          target->loc.repos_root_url);
 
@@ -6229,7 +6229,7 @@ get_wc_explicit_mergeinfo_catalog(apr_ha
               err = svn_error_createf(
                 SVN_ERR_CLIENT_INVALID_MERGEINFO_NO_MERGETRACKING, err,
                 _("Invalid mergeinfo detected on '%s', "
-                  "mergetracking not possible"),
+                  "merge tracking not possible"),
                 svn_dirent_local_style(wc_path, scratch_pool));
             }
           return svn_error_trace(err);
@@ -7378,7 +7378,7 @@ do_file_merge(svn_mergeinfo_catalog_t re
               err = svn_error_createf(
                 SVN_ERR_CLIENT_INVALID_MERGEINFO_NO_MERGETRACKING, err,
                 _("Invalid mergeinfo detected on merge target '%s', "
-                  "mergetracking not possible"),
+                  "merge tracking not possible"),
                 svn_dirent_local_style(target_abspath, scratch_pool));
             }
           return svn_error_trace(err);

Modified: subversion/branches/wc-collate-path/subversion/libsvn_client/ra.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/subversion/libsvn_client/ra.c?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- subversion/branches/wc-collate-path/subversion/libsvn_client/ra.c (original)
+++ subversion/branches/wc-collate-path/subversion/libsvn_client/ra.c Wed May  
8 14:34:57 2013
@@ -158,7 +158,7 @@ push_wc_prop(void *baton,
   if (! cb->commit_items)
     return svn_error_createf
       (SVN_ERR_UNSUPPORTED_FEATURE, NULL,
-       _("Attempt to set wc property '%s' on '%s' in a non-commit operation"),
+       _("Attempt to set wcprop '%s' on '%s' in a non-commit operation"),
        name, svn_dirent_local_style(relpath, pool));
 
   for (i = 0; i < cb->commit_items->nelts; i++)

Modified: subversion/branches/wc-collate-path/subversion/libsvn_ra_serf/serf.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/subversion/libsvn_ra_serf/serf.c?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- subversion/branches/wc-collate-path/subversion/libsvn_ra_serf/serf.c 
(original)
+++ subversion/branches/wc-collate-path/subversion/libsvn_ra_serf/serf.c Wed 
May  8 14:34:57 2013
@@ -119,8 +119,9 @@ load_http_auth_types(apr_pool_t *pool, s
             *authn_types |= SERF_AUTHN_NEGOTIATE;
           else
             return svn_error_createf(SVN_ERR_BAD_CONFIG_VALUE, NULL,
-                                     _("Invalid config: unknown http auth"
-                                       "type '%s'"), token);
+                                     _("Invalid config: unknown %s "
+                                       "'%s'"),
+                                     SVN_CONFIG_OPTION_HTTP_AUTH_TYPES, token);
       }
     }
   else

Modified: 
subversion/branches/wc-collate-path/subversion/libsvn_subr/cache-membuffer.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/subversion/libsvn_subr/cache-membuffer.c?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- 
subversion/branches/wc-collate-path/subversion/libsvn_subr/cache-membuffer.c 
(original)
+++ 
subversion/branches/wc-collate-path/subversion/libsvn_subr/cache-membuffer.c 
Wed May  8 14:34:57 2013
@@ -1501,7 +1501,7 @@ svn_cache__membuffer_cache_create(svn_me
         {
           /* We are OOM. There is no need to proceed with "half a cache".
            */
-          return svn_error_wrap_apr(APR_ENOMEM, _("OOM"));
+          return svn_error_wrap_apr(APR_ENOMEM, "OOM");
         }
 
 #if APR_HAS_THREADS

Modified: 
subversion/branches/wc-collate-path/subversion/libsvn_subr/sqlite3wrapper.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/subversion/libsvn_subr/sqlite3wrapper.c?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- subversion/branches/wc-collate-path/subversion/libsvn_subr/sqlite3wrapper.c 
(original)
+++ subversion/branches/wc-collate-path/subversion/libsvn_subr/sqlite3wrapper.c 
Wed May  8 14:34:57 2013
@@ -39,6 +39,17 @@
 #      pragma GCC diagnostic ignored "-Wshorten-64-to-32"
 #    endif
 #  endif
+#  ifdef __APPLE__
+#    include <Availability.h>
+#    if __MAC_OS_X_VERSION_MIN_REQUIRED < 1060
+       /* <libkern/OSAtomic.h> is included on OS X by sqlite3.c, and
+          on old systems (Leopard or older), it cannot be compiled
+          with -std=c89 because it uses inline. This is a work-around. */
+#      define inline __inline__
+#      include <libkern/OSAtomic.h>
+#      undef inline
+#    endif
+#  endif
 #  include <sqlite3.c>
 #  if __GNUC__ > 4 || (__GNUC__ == 4 && (__GNUC_MINOR__ >= 6))
 #    pragma GCC diagnostic pop

Modified: subversion/branches/wc-collate-path/subversion/po/sv.po
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/subversion/po/sv.po?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- subversion/branches/wc-collate-path/subversion/po/sv.po [UTF-8] (original)
+++ subversion/branches/wc-collate-path/subversion/po/sv.po [UTF-8] Wed May  8 
14:34:57 2013
@@ -14541,7 +14541,7 @@ msgid ""
 "                               NAME[=VALUE]\n"
 "  --non-interactive      : do no interactive prompting (default is to\n"
 "                           prompt only if standard input is a terminal)\n"
-"  --force-interactive    : do interactive propmting even if standard\n"
+"  --force-interactive    : do interactive prompting even if standard\n"
 "                           input is not a terminal\n"
 "  --trust-server-cert    : accept SSL server certificates from unknown\n"
 "                           certificate authorities without prompting (but\n"

Modified: subversion/branches/wc-collate-path/subversion/svnmucc/svnmucc.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/subversion/svnmucc/svnmucc.c?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- subversion/branches/wc-collate-path/subversion/svnmucc/svnmucc.c (original)
+++ subversion/branches/wc-collate-path/subversion/svnmucc/svnmucc.c Wed May  8 
14:34:57 2013
@@ -952,7 +952,7 @@ usage(apr_pool_t *pool, int exit_val)
       "                               NAME[=VALUE]\n"
       "  --non-interactive      : do no interactive prompting (default is to\n"
       "                           prompt only if standard input is a 
terminal)\n"
-      "  --force-interactive    : do interactive propmting even if standard\n"
+      "  --force-interactive    : do interactive prompting even if standard\n"
       "                           input is not a terminal\n"
       "  --trust-server-cert    : accept SSL server certificates from 
unknown\n"
       "                           certificate authorities without prompting 
(but\n"

Modified: 
subversion/branches/wc-collate-path/subversion/tests/libsvn_wc/wc-queries-test.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/subversion/tests/libsvn_wc/wc-queries-test.c?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- 
subversion/branches/wc-collate-path/subversion/tests/libsvn_wc/wc-queries-test.c
 (original)
+++ 
subversion/branches/wc-collate-path/subversion/tests/libsvn_wc/wc-queries-test.c
 Wed May  8 14:34:57 2013
@@ -32,6 +32,17 @@
 #ifdef SVN_SQLITE_INLINE
 /* Include sqlite3 inline, making all symbols private. */
   #define SQLITE_API static
+  #ifdef __APPLE__
+    #include <Availability.h>
+    #if __MAC_OS_X_VERSION_MIN_REQUIRED < 1060
+      /* <libkern/OSAtomic.h> is included on OS X by sqlite3.c, and
+         on old systems (Leopard or older), it cannot be compiled
+         with -std=c89 because it uses inline. This is a work-around. */
+      #define inline __inline__
+      #include <libkern/OSAtomic.h>
+      #undef inline
+    #endif
+  #endif
   #include <sqlite3.c>
 #else
   #include <sqlite3.h>

Modified: subversion/branches/wc-collate-path/tools/dev/build-svn-deps-win.pl
URL: 
http://svn.apache.org/viewvc/subversion/branches/wc-collate-path/tools/dev/build-svn-deps-win.pl?rev=1480294&r1=1480293&r2=1480294&view=diff
==============================================================================
--- subversion/branches/wc-collate-path/tools/dev/build-svn-deps-win.pl 
(original)
+++ subversion/branches/wc-collate-path/tools/dev/build-svn-deps-win.pl Wed May 
 8 14:34:57 2013
@@ -481,8 +481,8 @@ sub build_openssl {
   # remove the no-asm below and use ms\do_nasm.bat instead.
   
   # TODO: Enable openssl to use zlib.  openssl needs some patching to do
-       # this since it wants to look for zlib as zlib1.dll and as the httpd
-       # build instructions note you probably don't want to dynamic link zlib.
+  # this since it wants to look for zlib as zlib1.dll and as the httpd
+  # build instructions note you probably don't want to dynamic link zlib.
   
   # TODO: OpenSSL requires perl on the path since it uses perl without a full
   # path in the batch file and the makefiles.  Probably should determine
@@ -647,17 +647,18 @@ sub build_httpd {
   # ApacheMonitor build fails due a duplicate manifest, turn off
   # GenerateManifest
   insert_property_group('support\win32\ApacheMonitor.vcxproj',
-                        '<GenerateManifest>false</GenerateManifest>');
+                        '<GenerateManifest>false</GenerateManifest>',
+                        '.dupman');
 
   # Modules randomly fail due to an error about the CL.read.1.tlog file
   # already existing.  This is really because of the intermediate dirs
   # being shared between modules, but for the time being this works around
   # it.
   find(sub {
          if (/\.vcxproj$/) {
            insert_property_group($_, 
'<TrackFileAccess>false</TrackFileAccess>')
          }
-       }, 'modules');
+       }, 'modules', 'support');
 
   # The APR libraries have projects named libapr but produce output named 
@@ -647,17 +647,18 @@ sub build_httpd {
 
-  # Modules randomly fail due to an error about the CL.read.1.tlog file
-  # already existing.  This is really because of the intermediate dirs
-  # being shared between modules, but for the time being this works around
-  # it.
+  # Modules and support projects randomly fail due to an error about the
+  # CL.read.1.tlog file already existing.  This is really because of the
+  # intermediate dirs being shared between modules, but for the time being
+  # this works around it.
   find(sub {
          if (/\.vcxproj$/) {
libapr-1
   # The problem with this is in newer versions of Visual Studio TargetName 
defaults


Reply via email to